@@ -1,23 +1,31 @@
+extern crate path_absolutize;
+
 use std::env;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 use std::process::exit;
 
+use path_absolutize::Absolutize;
+
 #[derive(Debug)]
 pub struct AppArgs {
     pub script_name: String,
-    pub forwared: String,
+    pub forwarded: String,
     pub change_dir: PathBuf,
     pub command: String,
+    pub interactive: bool,
 }
 
+pub const COMMANDS_TO_FORWARD: &'static [&str] = &["install", "i", "add", "remove", "uninstall"];
+
 pub fn parse_args(args_vec: &[String]) -> AppArgs {
     let mut args_iter = args_vec.into_iter();
 
     let mut args = AppArgs {
         script_name: "".to_string(),
         change_dir: PathBuf::from(env::current_dir().as_ref().unwrap()),
-        forwared: "".to_string(),
+        forwarded: "".to_string(),
         command: "".to_string(),
+        interactive: false,
     };
 
     loop {
@@ -25,11 +33,13 @@ pub fn parse_args(args_vec: &[String]) -> AppArgs {
         match arg {
             Some(v) => {
                 if v.starts_with("-") {
-                    if args.script_name.is_empty() {
+                    if args.script_name.is_empty()
+                        && (args.command.is_empty() || args.command == "run")
+                    {
                         match v.as_ref() {
                             "-c" => {
                                 let dir = match args_iter.next() {
-                                    Some(v) => PathBuf::from(v),
+                                    Some(v) => PathBuf::from(Path::new(v).absolutize().unwrap()),
                                     None => {
                                         println!("No directory specified");
                                         exit(1);
@@ -41,6 +51,9 @@ pub fn parse_args(args_vec: &[String]) -> AppArgs {
                                 }
                                 args.change_dir = dir;
                             }
+                            "-i" | "--interactive" => {
+                                args.interactive = true;
+                            }
                             "-h" | "--help" => {
                                 print!("{}", get_help());
                                 std::process::exit(0);
@@ -55,21 +68,32 @@ pub fn parse_args(args_vec: &[String]) -> AppArgs {
                             }
                         }
                     } else {
-                        // forwared flags
-                        args.forwared.push_str(" ");
-                        args.forwared.push_str(&v);
+                        // forwarded flags
+                        args.forwarded.push_str(" ");
+                        args.forwarded.push_str(&v);
                     }
-                } else if v == "run" {
-                    args.command = v.to_string();
-                } else if args.script_name.is_empty() {
-                    args.script_name = match v.as_ref() {
-                        "t" => "test".to_string(),
+                } else if args.command.is_empty()
+                    && (COMMANDS_TO_FORWARD.contains(&v.as_str()) || v == "run")
+                {
+                    args.command = match v.as_ref() {
                         "i" => "install".to_string(),
                         _ => v.to_string(),
                     };
+                } else if (args.command.is_empty() || args.command == "run")
+                    && args.script_name.is_empty()
+                {
+                    args.command = "run".to_string();
+                    args.script_name = match v.as_ref() {
+                        "t" => "test".to_string(),
+                        _ => v.to_string(),
+                    };
                 } else {
-                    args.forwared.push_str(" ");
-                    args.forwared.push_str(&v);
+                    if args.interactive {
+                        eprintln!("You can't pass arguments to interactive mode");
+                        exit(1);
+                    }
+                    args.forwarded.push_str(" ");
+                    args.forwarded.push_str(&v);
                 }
             }
             None => break,
@@ -103,6 +127,7 @@ COMMANDS:
 
 FLAGS:
     -c <dir>              Change working directory
+    -i, --interactive     Interactive mode
     -h, --help            Prints help information
     -v, --version         Prints version number
 ",
@@ -127,7 +152,7 @@ mod tests {
     fn test_parse() {
         let args = parse_args(&vec_of_strings!["a", "b", "-c", "-d", "foo", "bar"]);
         assert_eq!(args.script_name, "a".to_string());
-        assert_eq!(args.forwared, " b -c -d foo bar".to_string());
+        assert_eq!(args.forwarded, " b -c -d foo bar".to_string());
     }
 
     #[test]
@@ -135,6 +160,6 @@ mod tests {
         let args = parse_args(&vec_of_strings!["-c", ".", "a"]);
         assert_eq!(args.script_name, "a".to_string());
         assert_eq!(args.change_dir, PathBuf::from("."));
-        assert_eq!(args.forwared, "".to_string());
+        assert_eq!(args.forwarded, "".to_string());
     }
 }
